@@ -8,39 +8,33 @@
 	Windows, Linux, Mac Os X.
 
 **Description:**
-	This module defines tests suite logging configuration.
+	Defines tests suite logging configuration.
 
 **Others:**
 
 """
 
 #**********************************************************************************************************************
-#***	External imports.
+#***	Future imports.
 #**********************************************************************************************************************
-import logging
-import sys
+from __future__ import unicode_literals
 
 #**********************************************************************************************************************
 #***	Internal imports.
 #**********************************************************************************************************************
-import foundations.core as core
-from manager.globals.constants import Constants
+import foundations.verbose
 
 #**********************************************************************************************************************
 #***	Module attributes.
 #**********************************************************************************************************************
 __author__ = "Thomas Mansencal"
-__copyright__ = "Copyright (C) 2008 - 2012 - Thomas Mansencal"
+__copyright__ = "Copyright (C) 2008 - 2014 - Thomas Mansencal"
 __license__ = "GPL V3.0 - http://www.gnu.org/licenses/"
 __maintainer__ = "Thomas Mansencal"
 __email__ = "thomas.mansencal@gmail.com"
 __status__ = "Production"
 
-__all__ = ["LOGGER", "LOGGING_CONSOLE_HANDLER"]
+__all__ = ["LOGGER"]
 
-LOGGER = logging.getLogger(Constants.logger)
-
-# Starting the console handler.
-LOGGING_CONSOLE_HANDLER = logging.StreamHandler(sys.__stdout__)
-LOGGING_CONSOLE_HANDLER.setFormatter(core.LOGGING_DEFAULT_FORMATTER)
-LOGGER.addHandler(LOGGING_CONSOLE_HANDLER)
+LOGGER = foundations.verbose.installLogger()
+foundations.verbose.getLoggingConsoleHandler()
